@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Provider/Simple.pm 6463 2007-04-11T04:02:39.921726Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Provider/Simple.pm 6402 2007-04-06T17:34:44.214589Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -7,7 +7,6 @@ package Gungho::Provider::Simple;
 use strict;
 use warnings;
 use base qw(Gungho::Provider);
-use Gungho::Request;
 
 __PACKAGE__->mk_accessors($_) for qw(requests);
 
@@ -19,23 +18,6 @@ sub new
     $self;
 }
 
-sub setup
-{
-    my $self = shift;
-
-    my $url = $self->config->{url};
-    if ($url && ! ref($url) ) {
-        $url = [ $url ];
-    }
-
-    foreach my $u (@$url) {
-        $self->add_request(
-            Gungho::Request->new(GET => $u)
-        );
-    }
-    $self->next::method(@_);
-}
-
 sub add_request
 {
     my ($self, $req) = @_;
@@ -45,22 +27,14 @@ sub add_request
     $self->has_requests(1);
 }
 
-*pushback_request = \&add_request;
-
-sub dispatch
+sub get_requests
 {
-    my ($self, $c) = @_;
+    my $self = shift;
 
-    my $requests = $self->requests;
+    my $list = $self->requests;
     $self->requests([]);
-    while (@$requests) {
-        $self->dispatch_request($c, shift @$requests);
-    }
-
-    if (scalar @{ $self->requests } <= 0) {
-        $self->has_requests(0);
-        $c->is_running(0);
-    }
+    $self->has_requests(0);
+    return @$list;
 }
 
 1;
@@ -83,18 +57,15 @@ Gungho::Provider::Simple - An In-Memory, Simple Provider
 
 Creates a new instance.
 
-=head2 setup($c)
-
-Sets up the provider.
-
 =head2 add_request($request)
 
 Adds a new request to the provider.
 
-=head2 pushback_request($request)
+=head2 get_requests()
+
+Returns the list of requests in the provider. The list is set to an empty
+list after the call, and has_requests is set to 0
 
-=head2 dispatch()
 
-dispatches the requests
 
 =cut
\ No newline at end of file
